==> ldapsaisie_1.2-1.tar.gz: ldapsaisie_clean/public_html/tmp/e101aa0b7cfe7381f14a35a23da1b6bd7a1e8abb.ls.LSformElement_uri_field.tpl.php <==
<?php /* Smarty version Smarty-3.1.21-dev, created on 2015-07-30 16:11:49
         compiled from "ls:LSformElement_uri_field.tpl" */ ?>
<?php /*%%SmartyHeaderCode:79759679255ba4cc56cbad4-13796147%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'e101aa0b7cfe7381f14a35a23da1b6bd7a1e8abb' => 
    array (
      0 => 'ls:LSformElement_uri_field.tpl',
      1 => 1346660312,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '79759679255ba4cc56cbad4-13796147',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'freeze' => 0,
    'value' => 0,
    'uriClass' => 0,
    'uriPrefix' => 0,
    'uriTarget' => 0,
    'noValueTxt' => 0,
    'attr_name' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_55ba4cc56ea340_57082343',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_55ba4cc56ea340_57082343')) {function content_55ba4cc56ea340_57082343($_smarty_tpl) {?><?php if ($_smarty_tpl->tpl_vars['freeze']->value) {?>
  <span class='LSformElement_text'>
  <?php if ($_smarty_tpl->tpl_vars['value']->value) {?>
    <a class='<?php echo $_smarty_tpl->tpl_vars['uriClass']->value;?>
' href='<?php echo $_smarty_tpl->tpl_vars['uriPrefix']->value;
echo $_smarty_tpl->tpl_vars['value']->value;?>
'<?php if ($_smarty_tpl->tpl_vars['uriTarget']->value) {?> target='<?php echo $_smarty_tpl->tpl_vars['uriTarget']->value;?>
'<?php }?>><?php echo $_smarty_tpl->tpl_vars['value']->value;?>
</a>
  <?php } else { ?>
    <?php echo $_smarty_tpl->tpl_vars['noValueTxt']->value;?>

  <?php }?>
  </span>
  <input type='hidden' name='<?php echo $_smarty_tpl->tpl_vars['attr_name']->value;?>
[]' class='LSformElement_text' value="<?php echo $_smarty_tpl->tpl_vars['value']->value;?>
"/>
<?php } else { ?>
  <input type='text' name='<?php echo $_smarty_tpl->tpl_vars['attr_name']->value;?>
[]' class='LSformElement_text <?php echo $_smarty_tpl->tpl_vars['uriClass']->value;?>
' value="<?php echo $_smarty_tpl->tpl_vars['value']->value;?>
" autocomplete="off"/>
<?php }?>
<?php }} ?>

==> ldapsaisie_1.3-2.tar.gz: ldapsaisie_clean/public_html/tmp/e101aa0b7cfe7381f14a35a23da1b6bd7a1e8abb.ls.LSformElement_uri_field.tpl.php <==
<?php /* Smarty version Smarty-3.1.21-dev, created on 2016-12-14 16:22:37
         compiled from "ls:LSformElement_uri_field.tpl" */ ?>
<?php /*%%SmartyHeaderCode:2074277937585171cdb81d26-50501785%%*/if(!defined('SMARTY_DIR')) exit('no direct access allowed');
$_valid = $_smarty_tpl->decodeProperties(array (
  'file_dependency' => 
  array (
    'e101aa0b7cfe7381f14a35a23da1b6bd7a1e8abb' => 
    array (
      0 => 'ls:LSformElement_uri_field.tpl',
      1 => 1472212472,
      2 => 'ls',
    ),
  ),
  'nocache_hash' => '2074277937585171cdb81d26-50501785',
  'function' => 
  array (
  ),
  'variables' => 
  array (
    'freeze' => 0,
    'value' => 0,
    'uriClass' => 0,
    'uriPrefix' => 0,
    'uriLinkTitle' => 0,
    'uriTarget' => 0,
    'noValueTxt' => 0,
    'attr_name' => 0,
  ),
  'has_nocache_code' => false,
  'version' => 'Smarty-3.1.21-dev',
  'unifunc' => 'content_585171cdb91728_46928818',
),false); /*/%%SmartyHeaderCode%%*/?>
<?php if ($_valid && !is_callable('content_585171cdb91728_46928818')) {function content_585171cdb91728_46928818($_smarty_tpl) {?><?php if ($_smarty_tpl->tpl_vars['freeze']->value) {?>
  <span class='LSformElement_text'>
  <?php if ($_smarty_tpl->tpl_vars['value']->value) {?>
    <a class='<?php echo $_smarty_tpl->tpl_vars['uriClass']->value;?>
' href='<?php echo $_smarty_tpl->tpl_vars['uriPrefix']->value;
echo $_smarty_tpl->tpl_vars['value']->value;?>
'<?php if ($_smarty_tpl->tpl_vars['uriLinkTitle']->value) {?> title='<?php echo $_smarty_tpl->tpl_vars['uriLinkTitle']->value;?>
'<?php }
if ($_smarty_tpl->tpl_vars['uriTarget']->value) {?> target='<?php echo $_smarty_tpl->tpl_vars['uriTarget']->value;?>
'<?php }?>><?php echo $_smarty_tpl->tpl_vars['value']->value;?>
</a>
  <?php } else { ?>
    <?php echo $_smarty_tpl->tpl_vars['noValueTxt']->value;?>

  <?php }?>
  </span>
  <input type='hidden' name='<?php echo $_smarty_tpl->tpl_vars['attr_name']->value;?>
[]' class='LSformElement_text' value="<?php echo $_smarty_tpl->tpl_vars['value']->value;?>
"/>
<?php } else { ?>
  <input type='text' name='<?php echo $_smarty_tpl->tpl_vars['attr_name']->value;?>
[]' class='LSformElement_text <?php echo $_smarty_tpl->tpl_vars['uriClass']->value;?>
' value="<?php echo $_smarty_tpl->tpl_vars['value']->value;?>
" autocomplete="off"/>
<?php }?>
<?php }} ?>
